# Todo

- colocar mostrar teclas não conhecidas como modo dev debug
- colocar log como default e deixar um comando para limpar logs
- colocar modo pasta ao invés de modo online
- colocar modo arquivo mais prático do que ter que adicionar repositório
- modelo de tabela e modelo de input output para fup, deixa só o mula com o tio
- remover o modo monocromático
- add modelo pra converter entre markdown table para testes e tio
- tempo label do lado to fixar label ao lado dos cases
- +- label ao lado do tab para habilitar e desabilitar
- +- no mesmo simbolo se possível

- corrigir o DiffBuilder para adicionar ou remover as bordas
- se colocar as bordas, adicionar automaticamente a borda da direita.
- ao invés de fazer o scrollbar do lado direito, fazer elem embaixo

- opção de mostrar quantos testes passaram no principal
- opção de rodar os testes no computador do aluno
- for each folder tko test folder --compact
- mover coruja dinamicamente ou cortar tarefas se passarem do máximo e não tiver o mouse over

## Feedback

- Como sua autonomia e compreensão das técnicas apresentadas na atividade.
- Autonomia: Uso de ajuda externa. (grupo, monitor, colega, copilot, chatgpt, internet, tutorial)
- Compreensão: Nível de compreensão do conteúdo em 4 níveis. (superficial, básico, funcional, profundo)
